@@ -42,14 +42,14 @@ class ConfigFile(BaseModel):
 
 
 
-def generate_deployment(identifier: str, version: str, module_path: str, deployed: dict, deployer: str,  scopes: List[str]) -> Deployment:
+def generate_deployment(identifier: str, version: str, module_path: str, deployed: dict, deployer: str,  scopes: List[str], with_definitions = True) -> Deployment:
 
     path = create_arkitekt_folder()
 
 
     config_file = os.path.join(path, f"deployments.yaml")
 
-    definitions = generate_definitions(module_path)
+    definitions = generate_definitions(module_path) if with_definitions else []
 
     deployment = Deployment(identifier=identifier, version=version, deployer=deployer, definitions=definitions, deployed=deployed, scopes=scopes)
 
