@@ -185,7 +185,8 @@ def search_username_in_docker_info(docker_info: str):
 @click.option('--dockerfile', help='The dockerfile to use')
 @click.option('--nopush', help='Skip push')
 @click.option('--tag', help='The tag to use')
-def port(version, dockerfile, nopush, tag):
+@click.option('--nodefs', help='Do not inspect definitions', is_flag=True)
+def port(version, dockerfile, nopush, tag, nodefs):
     """Deploys the arkitekt app to port"""
 
     manifest = load_manifest()
@@ -240,7 +241,7 @@ def port(version, dockerfile, nopush, tag):
 
     deployed["docker"] = tag
 
-    generate_deployment(identifier, version, entrypoint, deployed, "arkitekt.deployers.port.dockerbuild", manifest.scopes)
+    generate_deployment(identifier, version, entrypoint, deployed, "arkitekt.deployers.port.dockerbuild", manifest.scopes, with_definitions=not nodefs)
 
 
 def prompt_scopes():
